## ---------------------------------------------------------------------
##
## Copyright (C) 2012 - 2015 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE at
## the top level of the deal.II distribution.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "8.4.2")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "8")
SET(DEAL_II_VERSION_MINOR "4")
SET(DEAL_II_VERSION_SUBMINOR "2")
SET(DEAL_II_VERSION "8.4.2")

SET(DEAL_II_GIT_BRANCH "")
SET(DEAL_II_GIT_REVISION "")
SET(DEAL_II_GIT_SHORTREV "")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "DebugRelease")
SET(DEAL_II_BUILD_TYPES "DEBUG;RELEASE")


#
# Information about the project location
#

SET(DEAL_II_DOCHTML_RELDIR "share/doc/libdeal.ii-doc/html")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/libdeal.ii-doc")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/libdeal.ii-doc/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib/arm-linux-gnueabihf")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "share/cmake/deal.II")
SET(DEAL_II_SHARE_RELDIR "share/deal.ii/")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_SHARE_RELDIR}/macros/*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/arm-linux-gnueabihf-g++")
SET(DEAL_II_C_COMPILER "/usr/bin/arm-linux-gnueabihf-gcc")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fPIC -Wall -Wextra -Wpointer-arith -Wwrite-strings -Wsynth -Wsign-compare -Wswitch -Woverloaded-virtual -Wno-long-long  -Wno-literal-suffix -fopenmp-simd -std=c++14 -g -O2 -fdebug-prefix-map=/build/deal.ii-btMdUY/deal.ii-8.4.2=. -fstack-protector-strong -Wformat -Werror=format-security -Wdate-time -D_FORTIFY_SOURCE=2 -Wno-nonnull-compare -Wno-address -Wno-unused-local-typedefs")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-Og -ggdb -Wa,--compress-debug-sections")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-rdynamic -fuse-ld=gold -Wl,-Bsymbolic-functions -Wl,-z,relro -Wl,-rpath  -Wl,/usr/lib/openmpi/lib  -Wl,--enable-new-dtags -pthread")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "-ggdb")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "DEBUG")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")

#
# MPI runtime:
#

SET(DEAL_II_MPIEXEC "/usr/bin/mpiexec")
SET(DEAL_II_MPIEXEC_NUMPROC_FLAG "-np")
SET(DEAL_II_MPIEXEC_PREFLAGS "")
SET(DEAL_II_MPIEXEC_POSTFLAGS "")

#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II/bundled;/usr/lib/openmpi/include/openmpi/opal/mca/event/libevent2021/libevent;/usr/lib/openmpi/include/openmpi/opal/mca/event/libevent2021/libevent/include;/usr/lib/openmpi/include;/usr/lib/openmpi/include/openmpi;/usr/include;/usr/include/trilinos;/usr/include/hdf5/openmpi;/usr/include/suitesparse;/usr/include/petsc;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/include;/usr/include/oce;/usr/include/slepc")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "${DEAL_II_PATH}/lib/arm-linux-gnueabihf/libdeal.ii.g.so;/usr/lib/arm-linux-gnueabihf/libbz2.so;/usr/lib/openmpi/lib/libmpi_usempif08.so;/usr/lib/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/openmpi/lib/libmpi_mpifh.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pike-blackbox.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_trilinoscouplings.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_piro.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rol.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_muelu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_ifpack2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_amesos2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_tpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_sacado.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rythmos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu-adapters.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu-interface.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_moertel.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_locathyra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_locaepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_localapack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_loca.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_noxepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_noxlapack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_nox.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_phalanx.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_intrepid.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teko.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosbelos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosaztecoo.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosamesos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosml.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosifpack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack2-adapters.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasazitpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ModeLaplace.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasaziepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasazi.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_komplex.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_amesos2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_shylu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belostpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belosepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ml.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_zoltan2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pamgen_extras.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pamgen.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_amesos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_galeri-xpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_galeri-epetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_aztecoo.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_dpliris.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_isorropia.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_optipack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_xpetra-sup.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_xpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyratpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyraepetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyraepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyracore.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_epetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetrainout.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkostsqr.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetrakernels.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassiclinalg.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassic.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_triutils.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_globipack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_shards.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_zoltan.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_epetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_sacado.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rtop.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoskokkoscomm.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoskokkoscompat.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosremainder.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosnumerics.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoscomm.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosparameterlist.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoscore.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkosalgorithms.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkoscontainers.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkoscore.so;/usr/lib/libsmumps.so;/usr/lib/libdmumps.so;/usr/lib/libcmumps.so;/usr/lib/libzmumps.so;/usr/lib/libpord.so;/usr/lib/libmumps_common.so;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/libhdf5.so;/usr/lib/arm-linux-gnueabihf/libtbb.so;/usr/lib/arm-linux-gnueabihf/libz.so;/usr/lib/openmpi/lib/libmpi_cxx.so;/usr/lib/arm-linux-gnueabihf/libumfpack.so;/usr/lib/arm-linux-gnueabihf/libcholmod.so;/usr/lib/arm-linux-gnueabihf/libccolamd.so;/usr/lib/arm-linux-gnueabihf/libcolamd.so;/usr/lib/arm-linux-gnueabihf/libcamd.so;/usr/lib/arm-linux-gnueabihf/libsuitesparseconfig.so;/usr/lib/arm-linux-gnueabihf/libamd.so;rt;/usr/lib/libparpack.so;/usr/lib/libarpack.so;/usr/lib/arm-linux-gnueabihf/libboost_iostreams.so;/usr/lib/arm-linux-gnueabihf/libboost_serialization.so;/usr/lib/arm-linux-gnueabihf/libboost_system.so;/usr/lib/arm-linux-gnueabihf/libboost_thread.so;/usr/lib/arm-linux-gnueabihf/libboost_regex.so;/usr/lib/arm-linux-gnueabihf/libboost_chrono.so;/usr/lib/arm-linux-gnueabihf/libboost_date_time.so;/usr/lib/arm-linux-gnueabihf/libboost_atomic.so;pthread;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/arm-linux-gnueabihf/libmuparser.so;/usr/lib/arm-linux-gnueabihf/libnetcdf_c++.so;/usr/lib/arm-linux-gnueabihf/libnetcdf.so;/usr/lib/arm-linux-gnueabihf/libTKBO.so;/usr/lib/arm-linux-gnueabihf/libTKBool.so;/usr/lib/arm-linux-gnueabihf/libTKBRep.so;/usr/lib/arm-linux-gnueabihf/libTKernel.so;/usr/lib/arm-linux-gnueabihf/libTKFeat.so;/usr/lib/arm-linux-gnueabihf/libTKFillet.so;/usr/lib/arm-linux-gnueabihf/libTKG2d.so;/usr/lib/arm-linux-gnueabihf/libTKG3d.so;/usr/lib/arm-linux-gnueabihf/libTKGeomAlgo.so;/usr/lib/arm-linux-gnueabihf/libTKGeomBase.so;/usr/lib/arm-linux-gnueabihf/libTKHLR.so;/usr/lib/arm-linux-gnueabihf/libTKIGES.so;/usr/lib/arm-linux-gnueabihf/libTKMath.so;/usr/lib/arm-linux-gnueabihf/libTKMesh.so;/usr/lib/arm-linux-gnueabihf/libTKOffset.so;/usr/lib/arm-linux-gnueabihf/libTKPrim.so;/usr/lib/arm-linux-gnueabihf/libTKShHealing.so;/usr/lib/arm-linux-gnueabihf/libTKSTEP.so;/usr/lib/arm-linux-gnueabihf/libTKSTEPAttr.so;/usr/lib/arm-linux-gnueabihf/libTKSTEPBase.so;/usr/lib/arm-linux-gnueabihf/libTKSTL.so;/usr/lib/arm-linux-gnueabihf/libTKTopAlgo.so;/usr/lib/arm-linux-gnueabihf/libTKXSBase.so;/usr/lib/arm-linux-gnueabihf/libp4est.so;/usr/lib/arm-linux-gnueabihf/libsc.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;gfortran;m;c;/usr/lib/openmpi/lib/libmpi.so;/usr/lib/arm-linux-gnueabihf/libslepc.so;/usr/lib/arm-linux-gnueabihf/libpetsc.so")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/lib/arm-linux-gnueabihf/libdeal.ii.so;/usr/lib/arm-linux-gnueabihf/libbz2.so;/usr/lib/openmpi/lib/libmpi_usempif08.so;/usr/lib/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/openmpi/lib/libmpi_mpifh.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pike-blackbox.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_trilinoscouplings.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_piro.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rol.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_muelu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_ifpack2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_amesos2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_tpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos_sacado.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stokhos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rythmos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu-adapters.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu-interface.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_muelu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_moertel.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_locathyra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_locaepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_localapack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_loca.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_noxepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_noxlapack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_nox.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_phalanx.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_intrepid.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teko.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosbelos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosaztecoo.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosamesos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosml.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_stratimikosifpack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack2-adapters.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasazitpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ModeLaplace.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasaziepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_anasazi.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_komplex.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_amesos2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_shylu.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belostpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belosepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_belos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ml.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_ifpack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_zoltan2.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pamgen_extras.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_pamgen.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_amesos.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_galeri-xpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_galeri-epetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_aztecoo.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_dpliris.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_isorropia.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_optipack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_xpetra-sup.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_xpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyratpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyraepetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyraepetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_thyracore.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_epetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraext.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetrainout.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkostsqr.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetrakernels.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassiclinalg.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_tpetraclassic.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_triutils.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_globipack.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_shards.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_zoltan.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_epetra.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_sacado.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_rtop.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoskokkoscomm.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoskokkoscompat.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosremainder.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosnumerics.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoscomm.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchosparameterlist.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_teuchoscore.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkosalgorithms.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkoscontainers.so;/usr/lib/arm-linux-gnueabihf/libtrilinos_kokkoscore.so;/usr/lib/libsmumps.so;/usr/lib/libdmumps.so;/usr/lib/libcmumps.so;/usr/lib/libzmumps.so;/usr/lib/libpord.so;/usr/lib/libmumps_common.so;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/libhdf5.so;/usr/lib/arm-linux-gnueabihf/libtbb.so;/usr/lib/arm-linux-gnueabihf/libz.so;/usr/lib/openmpi/lib/libmpi_cxx.so;/usr/lib/arm-linux-gnueabihf/libumfpack.so;/usr/lib/arm-linux-gnueabihf/libcholmod.so;/usr/lib/arm-linux-gnueabihf/libccolamd.so;/usr/lib/arm-linux-gnueabihf/libcolamd.so;/usr/lib/arm-linux-gnueabihf/libcamd.so;/usr/lib/arm-linux-gnueabihf/libsuitesparseconfig.so;/usr/lib/arm-linux-gnueabihf/libamd.so;rt;/usr/lib/libparpack.so;/usr/lib/libarpack.so;/usr/lib/arm-linux-gnueabihf/libboost_iostreams.so;/usr/lib/arm-linux-gnueabihf/libboost_serialization.so;/usr/lib/arm-linux-gnueabihf/libboost_system.so;/usr/lib/arm-linux-gnueabihf/libboost_thread.so;/usr/lib/arm-linux-gnueabihf/libboost_regex.so;/usr/lib/arm-linux-gnueabihf/libboost_chrono.so;/usr/lib/arm-linux-gnueabihf/libboost_date_time.so;/usr/lib/arm-linux-gnueabihf/libboost_atomic.so;pthread;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/arm-linux-gnueabihf/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/arm-linux-gnueabihf/libmuparser.so;/usr/lib/arm-linux-gnueabihf/libnetcdf_c++.so;/usr/lib/arm-linux-gnueabihf/libnetcdf.so;/usr/lib/arm-linux-gnueabihf/libTKBO.so;/usr/lib/arm-linux-gnueabihf/libTKBool.so;/usr/lib/arm-linux-gnueabihf/libTKBRep.so;/usr/lib/arm-linux-gnueabihf/libTKernel.so;/usr/lib/arm-linux-gnueabihf/libTKFeat.so;/usr/lib/arm-linux-gnueabihf/libTKFillet.so;/usr/lib/arm-linux-gnueabihf/libTKG2d.so;/usr/lib/arm-linux-gnueabihf/libTKG3d.so;/usr/lib/arm-linux-gnueabihf/libTKGeomAlgo.so;/usr/lib/arm-linux-gnueabihf/libTKGeomBase.so;/usr/lib/arm-linux-gnueabihf/libTKHLR.so;/usr/lib/arm-linux-gnueabihf/libTKIGES.so;/usr/lib/arm-linux-gnueabihf/libTKMath.so;/usr/lib/arm-linux-gnueabihf/libTKMesh.so;/usr/lib/arm-linux-gnueabihf/libTKOffset.so;/usr/lib/arm-linux-gnueabihf/libTKPrim.so;/usr/lib/arm-linux-gnueabihf/libTKShHealing.so;/usr/lib/arm-linux-gnueabihf/libTKSTEP.so;/usr/lib/arm-linux-gnueabihf/libTKSTEPAttr.so;/usr/lib/arm-linux-gnueabihf/libTKSTEPBase.so;/usr/lib/arm-linux-gnueabihf/libTKSTL.so;/usr/lib/arm-linux-gnueabihf/libTKTopAlgo.so;/usr/lib/arm-linux-gnueabihf/libTKXSBase.so;/usr/lib/arm-linux-gnueabihf/libp4est.so;/usr/lib/arm-linux-gnueabihf/libsc.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;gfortran;m;c;/usr/lib/openmpi/lib/libmpi.so;/usr/lib/arm-linux-gnueabihf/libslepc.so;/usr/lib/arm-linux-gnueabihf/libpetsc.so")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "debug;${DEAL_II_LIBRARIES_DEBUG};optimized;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about library targets
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "deal.ii.g")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal.ii")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "debug;${DEAL_II_TARGET_DEBUG};optimized;${DEAL_II_TARGET_RELEASE}")


#
# Feature configuration:
#

SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ARPACK ON)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_BOOST_VERSION "1.61.0")
SET(DEAL_II_WITH_BZIP2 ON)
SET(DEAL_II_BZIP2_VERSION "1.0.6")
SET(DEAL_II_WITH_CXX11 ON)
SET(DEAL_II_WITH_CXX14 ON)
SET(DEAL_II_WITH_GSL ON)
SET(DEAL_II_WITH_HDF5 ON)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_WITH_METIS OFF)
SET(DEAL_II_WITH_MPI ON)
SET(DEAL_II_MPI_VERSION "3.0")
SET(DEAL_II_WITH_MUPARSER ON)
SET(DEAL_II_MUPARSER_VERSION "2.2.3")
SET(DEAL_II_WITH_NETCDF ON)
SET(DEAL_II_WITH_OPENCASCADE ON)
SET(DEAL_II_WITH_P4EST ON)
SET(DEAL_II_P4EST_VERSION "1.1")
SET(DEAL_II_WITH_PETSC ON)
SET(DEAL_II_PETSC_VERSION "3.7.3.0")
SET(DEAL_II_WITH_SLEPC ON)
SET(DEAL_II_SLEPC_VERSION "3.7.2.0")
SET(DEAL_II_WITH_THREADS ON)
SET(DEAL_II_WITH_TRILINOS ON)
SET(DEAL_II_TRILINOS_VERSION "12.6.4")
SET(DEAL_II_WITH_UMFPACK ON)
SET(DEAL_II_UMFPACK_VERSION "5.7.6")
SET(DEAL_II_WITH_ZLIB ON)
SET(DEAL_II_ZLIB_VERSION "1.2.8")
